@@ -37,8 +37,9 @@ def sync_k_line(str_day):
 
 
 if __name__ == '__main__':
-    str_day_01 = '2025-02-27'
-    sync_k_line(str_day_01)
+    sync_k_line('2025-08-27')
+    # sync_k_line('2025-07-24')
+    # sync_k_line('2025-07-25')
     # sync_k_line(str_day_01)
     # sync_k_line('2024-11-13')
     # sync_k_line('2024-11-12')
