@@ -142,8 +142,8 @@ def sync_miss_report(sync_time):
 
 
 if __name__ == '__main__':
-    now_date = datetime.now()
-    now_year = now_date.year
-    now_month = now_date.month
-    sync_time_test = now_date.strftime('%Y-%m-%d %H:%M:%S')
+    now_date_test = datetime.now()
+    now_year_test = now_date_test.year
+    now_month_test = now_date_test.month
+    sync_time_test = now_date_test.strftime('%Y-%m-%d %H:%M:%S')
     sync_financial_report()
