@@ -28,6 +28,7 @@ def sync_stock_tfp(str_day):
         stock_tfp_df['sus_begin_time'] = stock_tfp_df['sus_begin_time'].astype(str)
         stock_tfp_df['sus_end_time'] = stock_tfp_df['sus_end_time'].astype(str)
         stock_tfp_df['resume_time'] = stock_tfp_df['resume_time'].astype(str)
+        stock_tfp_df['sus_begin_date'] = stock_tfp_df['sus_begin_date'].astype(str)
         stock_tfp_df = common_service_fun_api.exclude_st_symbol(stock_tfp_df)
         # 根据条件设置新列'type'的值
 
@@ -43,11 +44,13 @@ def sync_stock_tfp(str_day):
         stock_tfp_df.loc[stock_tfp_df['type'] == '2', 'valid'] = False
         stock_tfp_df.loc[stock_tfp_df['type'] == '1', 'valid'] = False
 
+        stock_tfp_df = stock_tfp_df.fillna(0)
+
         mongodb_util.save_mongo(stock_tfp_df, db_name_constant.STOCK_TFP_INFO)
 
     return stock_tfp_df
 
 
 if __name__ == '__main__':
-    df = sync_stock_tfp('2024-12-05')
+    df = sync_stock_tfp('2025-07-30')
     print(df)
