@@ -24,7 +24,6 @@ import mns_scheduler.k_line.month_week_daily.daily_week_month_line_sync as daily
 import mns_scheduler.company_info.announce.company_announce_sync_service as company_announce_sync_service
 import mns_scheduler.db.col_move_service as col_move_service
 import mns_scheduler.db.db_status as db_status_api
-import mns_scheduler.big_deal.ths_big_deal_sync as ths_big_deal_sync_api
 import mns_scheduler.zt.open_data.kcx_high_chg_open_data_sync as kcx_high_chg_open_data_sync
 import mns_scheduler.zt.export.export_kcx_high_chg_open_data_to_excel as export_kcx_high_chg_open_data_to_excel
 import mns_scheduler.zt.connected_boards.zt_five_boards_sync_api as zt_five_boards_sync_api
@@ -61,7 +60,6 @@ import mns_scheduler.zt.zt_pool.update_null_zt_reason_api as update_null_zt_reas
 import mns_scheduler.trade.tfp.stock_tfp_info_sync as stock_tfp_info_sync
 import mns_scheduler.industry.ths.ths_industry_sync_service as ths_industry_sync_service
 import mns_scheduler.k_line.year_quarter.year_quarter_line_sync as year_quarter_line_sync
-import mns_common.component.task.real_time_data_sync_check as real_time_data_sync_check
 
 
 # 同步交易日期任务完成
@@ -123,13 +121,13 @@ def db_status_check():
     db_status_api.db_status_check()
 
 
-# 同步大单数据
-def sync_ths_big_deal():
-    now_date = datetime.now()
-    str_now_day = now_date.strftime('%Y-%m-%d')
-    if trade_date_common_service_api.is_trade_day(str_now_day):
-        logger.info('更新大单数据')
-        ths_big_deal_sync_api.sync_ths_big_deal(False)
+# # 同步大单数据
+# def sync_ths_big_deal():
+#     now_date = datetime.now()
+#     str_now_day = now_date.strftime('%Y-%m-%d')
+#     if trade_date_common_service_api.is_trade_day(str_now_day):
+#         logger.info('更新大单数据')
+#         ths_big_deal_sync_api.sync_ths_big_deal(False)
 
 
 # 定时同步每日交易行情数据(前复权)
@@ -184,7 +182,11 @@ def generate_new_day_k_line_info():
     now_date = datetime.now()
     str_day = now_date.strftime('%Y-%m-%d')
     # 生成下一个交易日日期k线数据 number=2 获取下一个交易日 日期
-    next_trade_day = trade_date_common_service_api.get_further_trade_date(str_day, 2)
+    if trade_date_common_service_api.is_trade_day(str_day):
+        dis_number = 2
+    else:
+        dis_number = 1
+    next_trade_day = trade_date_common_service_api.get_further_trade_date(str_day, dis_number)
     k_line_info_clean_service.sync_k_line_info_task(next_trade_day)
     logger.info('计算当日k线信息完成:{}', str_day)
 
@@ -346,23 +348,23 @@ def sync_high_risk_stocks():
 def sync_all_interactive_questions():
     now_date = datetime.now()
     str_day = now_date.strftime('%Y-%m-%d')
-    hour = now_date.hour
-    tag = (bool(1 - trade_date_common_service_api.is_trade_day(str_day))) or (hour >= 17)
+    # 非交易日同步
+    tag = bool(1 - trade_date_common_service_api.is_trade_day(str_day))
     if tag:
         logger.info('同步互动回答')
         stock_irm_cninfo_service.sync_all_interactive_questions(None)
 
 
-# 重开定时任务同步
-def real_time_sync_task_open():
-    logger.info("开启实时行情同步任务")
-    real_time_data_sync_check.real_time_sync_task_open()
+# # 重开定时任务同步
+# def real_time_sync_task_open():
+#     logger.info("开启实时行情同步任务")
+#     real_time_data_sync_check.real_time_sync_task_open()
 
-
-# 关闭实时行情任务
-def real_time_sync_task_close():
-    logger.info("关闭实时行情同步任务")
-    real_time_data_sync_check.real_time_sync_task_close()
+#
+# # 关闭实时行情任务
+# def real_time_sync_task_close():
+#     logger.info("关闭实时行情同步任务")
+#     real_time_data_sync_check.real_time_sync_task_close()
 
 
 # 打开交易客户端
@@ -407,7 +409,7 @@ def update_null_zt_reason():
 
 # 同步公告信息
 def sync_company_announce():
-    company_announce_sync_service.sync_company_announce()
+    company_announce_sync_service.sync_company_announce(None)
 
 
 # 同步停复牌信息
@@ -452,6 +454,9 @@ blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='07,08,18
 # 打开交易客户端
 blockingScheduler.add_job(trader_client_auto_login, 'cron', hour='08,09', minute='04')
 
+# 获取当前持仓
+blockingScheduler.add_job(sync_position, 'cron', hour='0,08,09', minute='14')
+
 # 同步公司基本信息
 blockingScheduler.add_job(update_company_base_info, 'cron', hour='08,18', minute='05')
 
@@ -473,28 +478,14 @@ blockingScheduler.add_job(self_choose_stock_task, 'cron', hour='08,17,21', minut
 # 开盘前同步同花顺新概念指数
 blockingScheduler.add_job(sync_new_concept_index, 'cron', hour='09,22', minute='01,10,20,28,41,58')
 
-# 获取同花顺持仓
-blockingScheduler.add_job(sync_position, 'cron', hour='0,08,09', minute='14')
-
 # 更新同花顺概念信息
 blockingScheduler.add_job(concept_info_clean, 'cron', hour='9,12,20', minute='24')
 
 # 更新开盘啦指数关系
 blockingScheduler.add_job(update_best_choose_plate_relation, 'cron', hour='09,18', minute='25')
 
-# 打开实时行情任务同步
-
-blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='15')
-blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='09', minute='29')
-blockingScheduler.add_job(real_time_sync_task_open, 'cron', hour='12', minute='59')
-# 关闭实时行情任务
-
-blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='09', minute='28')
-blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='11', minute='31')
-blockingScheduler.add_job(real_time_sync_task_close, 'cron', hour='15', minute='01')
-
 # 自动打新 打新中签高时间段 10:30-11:30
-blockingScheduler.add_job(auto_ipo_buy, 'cron', hour='10', minute='40,50')
+blockingScheduler.add_job(auto_ipo_buy, 'cron', hour='09', minute='40,50')
 
 # 同步单只股票下所有概念 by 股票代码 中午任务执行
 blockingScheduler.add_job(update_one_symbol_all_concepts, 'cron', hour='12', minute='15,40')
@@ -565,5 +556,4 @@ print('定时任务启动成功')
 blockingScheduler.start()
 #
 # if __name__ == '__main__':
-#
-#     sync_daily_data_info()
+#     generate_new_day_k_line_info()
